CREATE TABLE chrlengths(
                chromosome VARCHAR(2) PRIMARY KEY,
                length INTEGER NOT NULL);
CREATE TABLE chromosome_locations (
                _id INTEGER NOT NULL,
                seqname VARCHAR(20) NOT NULL,
                start_location INTEGER NOT NULL,
                gene_start INTEGER DEFAULT NULL,
                gene_end INTEGER DEFAULT NULL,
                gene_strand INTEGER DEFAULT NULL,
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE chromosomes (
                _id INTEGER NOT NULL,
                chromosome VARCHAR(2) NOT NULL,
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE cytogenetic_locations (
                _id INTEGER NOT NULL,
                cytogenetic_location VARCHAR(20),
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE embl (
                _id INTEGER NOT NULL,
                embl_id VARCHAR(10),
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE ensembl (
                _id INTEGER NOT NULL,
                ensembl_id VARCHAR(20),
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE ensembl_transcript (
                _id INTEGER NOT NULL,
                ensembl_transcript_id VARCHAR(20));
CREATE TABLE gene_info (
                _id INTEGER NOT NULL,
                gene_name VARCHAR(255),
                symbol VARCHAR(80),
                biotype VARCHAR(40),
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE genes (
                _id INTEGER NOT NULL,
                gene_id VARCHAR(10),
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE go (
                _id INTEGER NOT NULL,
                go_id CHAR(10),
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE map_counts (
                map_name VARCHAR(80) PRIMARY KEY,
                count INTEGER NOT NULL);
CREATE TABLE map_metadata (
                map_name VARCHAR(80) NOT NULL,
                source_name VARCHAR(80) NOT NULL,
                source_url VARCHAR(255) NOT NULL,
                source_date VARCHAR(20) NOT NULL,
                source_version VARCHAR(4) NOT NULL);
CREATE TABLE metadata (
                name VARCHAR(80) PRIMARY KEY,
                value VARCHAR(255));
CREATE TABLE probes (
                _id INTEGER PRIMARY KEY AUTOINCREMENT,
                probeset_id VARCHAR(150) NOT NULL UNIQUE,
                ensembl_id VARCHAR(20),
                probe_qty INTEGER NOT NULL,
                transcript_mapped INTEGER NOT NULL,
                transcript_total INTEGER NOT NULL,
                gene_mapped INTEGER NOT NULL);
CREATE TABLE refseq (
                _id INTEGER NOT NULL,
                accession VARCHAR(20),
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE unigene (
                _id INTEGER NOT NULL,
                unigene_id VARCHAR(10),
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE TABLE uniprot (
                _id INTEGER NOT NULL,
                uniprot_id VARCHAR(20),
                FOREIGN KEY (_id) REFERENCES probes (_id));
CREATE INDEX Fchromosome_locations ON chromosome_locations (_id);
CREATE INDEX Fchromosomes ON chromosomes (_id);
CREATE INDEX Fcytogenic_locations ON cytogenetic_locations (_id);
CREATE INDEX Fensembl_ensembl_id ON ensembl (ensembl_id);
CREATE INDEX Fensembl_id ON ensembl (_id);
CREATE INDEX Fensemblt ON ensembl_transcript (_id);
CREATE INDEX Fensemblt_ensemblt_id ON ensembl_transcript (ensembl_transcript_id);
CREATE INDEX Fgene_info ON gene_info (_id);
CREATE INDEX Fgenes ON genes (_id);
CREATE INDEX Fgenes_gene_id ON genes (gene_id);
CREATE INDEX Fgo ON go (_id);
CREATE INDEX Fgo_go_id ON go (go_id);
CREATE INDEX Fprobes_ensembl_id ON probes (ensembl_id);
CREATE INDEX Fprobes_probeset_id ON probes (probeset_id);
CREATE INDEX Frefseq ON refseq (_id);
CREATE INDEX Frefseq_accession ON refseq (accession);
CREATE INDEX Funigene ON unigene (_id);
CREATE INDEX Funigene_unigene_id ON unigene (unigene_id);
CREATE INDEX Funiprot ON uniprot (_id);
CREATE INDEX Funiprot_uniprot_id ON uniprot (uniprot_id);
